@@ -1,34 +1,18 @@
 # -*- coding: utf-8 -*-
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 #   Copyright 2009 - 2013   Clark Williams <williams@redhat.com>
 #   Copyright 2012 - 2013   David Sommerseth <davids@redhat.com>
 #
-#   This program is free software; you can redistribute it and/or modify
-#   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
-#   (at your option) any later version.
-#
-#   This program is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
-#
-#   You should have received a copy of the GNU General Public License along
-#   with this program; if not, write to the Free Software Foundation, Inc.,
-#   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
-#   For the avoidance of doubt the "preferred form" of this code is one which
-#   is in an open unpatent encumbered format. Where cryptographic key signing
-#   forms part of the process of creating an executable the information
-#   including keys needed to generate an equivalently functional executable
-#   are deemed to be part of the source code.
-#
 
-import os, shutil, subprocess, libxml2
+import os
+import shutil
+import subprocess
 from glob import glob
+import libxml2
 from rteval.Log import Log
 
-class OSInfo(object):
+class OSInfo:
     def __init__(self, logger):
         self.__logger = logger
 
@@ -52,30 +36,38 @@ class OSInfo(object):
             shutil.copyfile(dpath, os.path.join(repdir, "dmesg"))
             return
         if os.path.exists('/usr/bin/dmesg'):
-            subprocess.call('/usr/bin/dmesg > %s' % os.path.join(repdir, "dmesg"), shell=True)
+            subprocess.call(f'/usr/bin/dmesg > {os.path.join(repdir, "dmesg")}', shell=True)
             return
-        print("dmesg file not found at %s and no dmesg exe found!" % dpath)
+        print(f"dmesg file not found at {dpath} and no dmesg exe found!")
 
 
 
     def run_sysreport(self, repdir):
-        if os.path.exists('/usr/sbin/sosreport'):
+        if os.path.exists('/usr/sbin/sos'):
+            exe = '/usr/sbin/sos report'
+        elif os.path.exists('/usr/bin/sos'):
+            exe = '/usr/bin/sos report'
+        elif os.path.exists('/usr/sbin/sosreport'):
             exe = '/usr/sbin/sosreport'
+        elif os.path.exists('/usr/bin/sosreport'):
+            exe = '/usr/bin/sosreport'
         elif os.path.exists('/usr/sbin/sysreport'):
             exe = '/usr/sbin/sysreport'
+        elif os.path.exists('/usr/bin/sysreport'):
+            exe = '/usr/bin/sysreport'
         else:
-            raise RuntimeError("Can't find sosreport/sysreport")
+            raise RuntimeError("Can't find sos/sosreport/sysreport")
 
-        self.__logger.log(Log.DEBUG, "report tool: %s" % exe)
-        options =  ['-k', 'rpm.rpmva=off',
-                    '--name=rteval',
-                    '--batch']
+        self.__logger.log(Log.DEBUG, f"report tool: {exe}")
+        options = ['-k', 'rpm.rpmva=off',
+                   '--name=rteval',
+                   '--batch']
 
         self.__logger.log(Log.INFO, "Generating SOS report")
-        self.__logger.log(Log.INFO, "using command %s" % " ".join([exe]+options))
-        subprocess.call([exe] + options)
+        self.__logger.log(Log.INFO, f"using command {' '.join(exe.split()+options)}")
+        subprocess.call(exe.split() + options)
         for s in glob('/tmp/s?sreport-rteval-*'):
-            self.__logger.log(Log.DEBUG, "moving %s to %s" % (s, repdir))
+            self.__logger.log(Log.DEBUG, f"moving {s} to {repdir}")
             shutil.move(s, repdir)
 
 
@@ -88,7 +80,7 @@ class OSInfo(object):
 
         (sys, node, release, ver, machine) = os.uname()
         isrt = 1
-        if ver.find(' RT ') == -1:
+        if 'RT ' not in ver:
             isrt = 0
 
         node_n = libxml2.newNode("node")
@@ -115,13 +107,13 @@ def unit_test(rootdir):
         log = Log()
         log.SetLogVerbosity(Log.DEBUG|Log.INFO)
         osi = OSInfo(logger=log)
-        print("Base OS: %s" % osi.get_base_os())
+        print(f"Base OS: {osi.get_base_os()}")
 
         print("Testing OSInfo::copy_dmesg('/tmp'): ", end=' ')
         osi.copy_dmesg('/tmp')
-        if os.path.isfile("/tmp/dmesg"):
-            md5orig = subprocess.check_output(("md5sum","/var/log/dmesg"))
-            md5copy = subprocess.check_output(("md5sum","/tmp/dmesg"))
+        if os.path.isfile("/tmp/dmesg") and os.path.isfile("/var/log/dmesg"):
+            md5orig = subprocess.check_output(("md5sum", "/var/log/dmesg"))
+            md5copy = subprocess.check_output(("md5sum", "/tmp/dmesg"))
             if md5orig.split(" ")[0] == md5copy.split(" ")[0]:
                 print("PASS")
             else:
